@@ -20,7 +20,8 @@
 krb5_error_code
 krb524_convert_creds_kdc __P((
 	krb5_context context,
-	krb5_creds *v5creds,
+	krb5_ccache ccache,
+	krb5_creds *in_cred,
 	struct credentials *v4creds));
 
 krb5_error_code
@@ -64,6 +65,11 @@ krb5_abortx __P((
 	...))
     __attribute__ ((noreturn, format (printf, 2, 3)));
 
+krb5_error_code
+krb5_add_et_list __P((
+	krb5_context context,
+	void (*func)(struct et_list **)));
+
 krb5_error_code
 krb5_add_extra_addresses __P((
 	krb5_context context,
@@ -327,7 +333,7 @@ krb5_cc_close __P((
 krb5_error_code
 krb5_cc_copy_cache __P((
 	krb5_context context,
-	krb5_ccache from,
+	const krb5_ccache from,
 	krb5_ccache to));
 
 krb5_error_code
@@ -346,7 +352,7 @@ krb5_cc_destroy __P((
 krb5_error_code
 krb5_cc_end_seq_get __P((
 	krb5_context context,
-	krb5_ccache id,
+	const krb5_ccache id,
 	krb5_cc_cursor *cursor));
 
 krb5_error_code
@@ -374,7 +380,7 @@ krb5_cc_get_type __P((
 krb5_error_code
 krb5_cc_get_version __P((
 	krb5_context context,
-	krb5_ccache id));
+	const krb5_ccache id));
 
 krb5_error_code
 krb5_cc_initialize __P((
@@ -385,7 +391,7 @@ krb5_cc_initialize __P((
 krb5_error_code
 krb5_cc_next_cred __P((
 	krb5_context context,
-	krb5_ccache id,
+	const krb5_ccache id,
 	krb5_creds *creds,
 	krb5_cc_cursor *cursor));
 
@@ -405,7 +411,7 @@ krb5_cc_remove_cred __P((
 krb5_error_code
 krb5_cc_resolve __P((
 	krb5_context context,
-	const char *residual,
+	const char *name,
 	krb5_ccache *id));
 
 krb5_error_code
@@ -413,7 +419,7 @@ krb5_cc_retrieve_cred __P((
 	krb5_context context,
 	krb5_ccache id,
 	krb5_flags whichfields,
-	krb5_creds *mcreds,
+	const krb5_creds *mcreds,
 	krb5_creds *creds));
 
 krb5_error_code
@@ -425,7 +431,7 @@ krb5_cc_set_flags __P((
 krb5_error_code
 krb5_cc_start_seq_get __P((
 	krb5_context context,
-	krb5_ccache id,
+	const krb5_ccache id,
 	krb5_cc_cursor *cursor));
 
 krb5_error_code
@@ -468,8 +474,8 @@ krb5_boolean
 krb5_compare_creds __P((
 	krb5_context context,
 	krb5_flags whichfields,
-	krb5_creds *mcreds,
-	krb5_creds *creds));
+	const krb5_creds *mcreds,
+	const krb5_creds *creds));
 
 krb5_error_code
 krb5_config_file_free __P((
@@ -556,6 +562,13 @@ krb5_config_parse_file __P((
 	const char *fname,
 	krb5_config_section **res));
 
+krb5_error_code
+krb5_config_parse_file_debug __P((
+	const char *fname,
+	krb5_config_section **res,
+	unsigned *lineno,
+	char **error_message));
+
 const void *
 krb5_config_vget __P((
 	krb5_context context,
@@ -658,6 +671,12 @@ krb5_copy_data __P((
 	const krb5_data *indata,
 	krb5_data **outdata));
 
+krb5_error_code
+krb5_copy_host_realm __P((
+	krb5_context context,
+	const krb5_realm *from,
+	krb5_realm **to));
+
 krb5_error_code
 krb5_copy_keyblock __P((
 	krb5_context context,
@@ -919,7 +938,7 @@ krb5_enctype_valid __P((
 	krb5_enctype etype));
 
 krb5_boolean
-krb5_enctypes_comptible_keys __P((
+krb5_enctypes_compatible_keys __P((
 	krb5_context context,
 	krb5_enctype etype1,
 	krb5_enctype etype2));
@@ -941,6 +960,12 @@ krb5_errx __P((
 	...))
     __attribute__ ((noreturn, format (printf, 3, 4)));
 
+krb5_error_code
+krb5_expand_hostname __P((
+	krb5_context context,
+	const char *orig_hostname,
+	char **new_hostname));
+
 PA_DATA *
 krb5_find_padata __P((
 	PA_DATA *val,
@@ -1125,6 +1150,11 @@ krb5_get_default_realm __P((
 	krb5_context context,
 	krb5_realm *realm));
 
+krb5_error_code
+krb5_get_default_realms __P((
+	krb5_context context,
+	krb5_realm **realms));
+
 const char *
 krb5_get_err_text __P((
 	krb5_context context,
@@ -1156,6 +1186,12 @@ krb5_get_host_realm __P((
 	const char *host,
 	krb5_realm **realms));
 
+krb5_error_code
+krb5_get_host_realm_int __P((
+	krb5_context context,
+	const char *host,
+	krb5_realm **realms));
+
 krb5_error_code
 krb5_get_in_cred __P((
 	krb5_context context,
@@ -1389,6 +1425,13 @@ krb5_keytype_to_enctypes __P((
 	unsigned *len,
 	int **val));
 
+krb5_error_code
+krb5_keytype_to_enctypes_default __P((
+	krb5_context context,
+	krb5_keytype keytype,
+	unsigned *len,
+	int **val));
+
 krb5_error_code
 krb5_keytype_to_string __P((
 	krb5_context context,
@@ -1406,6 +1449,14 @@ krb5_kt_close __P((
 	krb5_context context,
 	krb5_keytab id));
 
+krb5_boolean
+krb5_kt_compare __P((
+	krb5_context context,
+	krb5_keytab_entry *entry,
+	krb5_const_principal principal,
+	krb5_kvno vno,
+	krb5_enctype enctype));
+
 krb5_error_code
 krb5_kt_copy_entry_contents __P((
 	krb5_context context,
@@ -1469,7 +1520,7 @@ krb5_kt_read_service_key __P((
 krb5_error_code
 krb5_kt_register __P((
 	krb5_context context,
-	krb5_kt_ops *ops));
+	const krb5_kt_ops *ops));
 
 krb5_error_code
 krb5_kt_remove_entry __P((
@@ -1514,6 +1565,12 @@ krb5_log_msg __P((
 	...))
     __attribute__((format (printf, 5, 6)));
 
+krb5_error_code
+krb5_make_addrport __P((
+	krb5_address **res,
+	const krb5_address *addr,
+	int16_t port));
+
 krb5_error_code
 krb5_make_principal __P((
 	krb5_context context,
@@ -1758,6 +1815,18 @@ krb5_recvauth __P((
 	krb5_keytab keytab,
 	krb5_ticket **ticket));
 
+krb5_error_code
+krb5_recvauth_match_version __P((
+	krb5_context context,
+	krb5_auth_context *auth_context,
+	krb5_pointer p_fd,
+	krb5_boolean (*match_appl_version)(void *, const char*),
+	void *match_data,
+	krb5_principal server,
+	int32_t flags,
+	krb5_keytab keytab,
+	krb5_ticket **ticket));
+
 krb5_error_code
 krb5_ret_address __P((
 	krb5_storage *sp,
@@ -1904,6 +1973,11 @@ krb5_sockaddr2address __P((
 	const struct sockaddr *sa,
 	krb5_address *addr));
 
+krb5_error_code
+krb5_sockaddr2port __P((
+	const struct sockaddr *sa,
+	int16_t *port));
+
 krb5_boolean
 krb5_sockaddr_uninteresting __P((const struct sockaddr *sa));
 
@@ -2067,6 +2141,13 @@ krb5_string_to_keytype __P((
 	const char *string,
 	krb5_keytype *keytype));
 
+krb5_error_code
+krb5_string_to_salttype __P((
+	krb5_context context,
+	krb5_enctype etype,
+	const char *string,
+	krb5_salttype *salttype));
+
 krb5_error_code
 krb5_timeofday __P((
 	krb5_context context,
@@ -2172,6 +2253,15 @@ krb5_verify_user __P((
 	krb5_boolean secure,
 	const char *service));
 
+krb5_error_code
+krb5_verify_user_lrealm __P((
+	krb5_context context,
+	krb5_principal principal,
+	krb5_ccache ccache,
+	const char *password,
+	krb5_boolean secure,
+	const char *service));
+
 krb5_error_code
 krb5_verr __P((
 	krb5_context context,
